@@ -1,5 +1,5 @@
 #
-# $Id: Jcode.pm,v 0.82 2002/09/23 18:30:03 dankogai Exp dankogai $
+# $Id: Jcode.pm,v 0.85 2004/06/18 18:32:19 dankogai Exp dankogai $
 #
 
 =head1 NAME
@@ -39,8 +39,8 @@ use Carp;
 use strict;
 use vars qw($RCSID $VERSION $DEBUG);
 
-$RCSID = q$Id: Jcode.pm,v 0.82 2002/09/23 18:30:03 dankogai Exp dankogai $;
-$VERSION = do { my @r = (q$Revision: 0.82 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$RCSID = q$Id: Jcode.pm,v 0.85 2004/06/18 18:32:19 dankogai Exp dankogai $;
+$VERSION = do { my @r = (q$Revision: 0.85 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 $DEBUG = 0;
 
 use Exporter;
@@ -300,9 +300,13 @@ sub _add_encoded_word {
 	    $line = ' ';
 	}
 	while (1) {
+	    my $iso_2022_jp = jcode($target, 'euc')->iso_2022_jp;
+	    if (my $count = ($iso_2022_jp =~ tr/\x80-\xff//d)){
+		$DEBUG and warn $count;
+		$target = jcode($iso_2022_jp, 'iso_2022_jp')->euc;
+	    }
 	    my $encoded = '=?ISO-2022-JP?B?' .
-	      MIME::Base64::encode_base64(
-					  jcode($target, 'euc')->iso_2022_jp, '') 
+	      MIME::Base64::encode_base64($iso_2022_jp, '')
 		  . '?=';
 	    if (length($encoded) + length($line) > $bpl) {
 		$target =~ 
@@ -600,6 +604,7 @@ sub getcode {
 	    while $$r_str =~ /((?:$RE{EUC_C}|$RE{EUC_KANA}|$RE{EUC_0212})+)/go;
 	$utf8  += length($1) 
 	    while $$r_str =~ /((?:$RE{UTF8})+)/go;
+	$utf8 *= 1.5; # M. Takahashi's suggestion
 	$nmatch = _max($utf8, $sjis, $euc);
 	carp ">DEBUG:sjis = $sjis, euc = $euc, utf8 = $utf8" if $DEBUG >= 3;
 	$code = 
